--
-- FrontloaderAttacher
-- Specialization for FrontloaderAttacher
--
-- @author  	Manuel Leithner (SFM-Modding)
-- @version 	v2.0
-- @date  		15/10/10
-- @history:	v1.0 - Initial version
--				v2.0 - converted to 2011 and some bugfixes
---- Edited by Henly20 (Ls_uk Modteam) 23-12-2010 For auto level on the Manitou Telehandler

JCBFrontloader = {};

function JCBFrontloader.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Cylindered, specializations);
end;

function JCBFrontloader:load(xmlFile)	

	
	local frontloader = {};
	local name = "vehicle.frontloader";

	local mainArm = {};
	mainArm.node = Utils.indexToObject(self.components, getXMLString(xmlFile, name .. ".mainArm#index"));
	mainArm.detachLimit = math.rad(getXMLFloat(xmlFile, name .. ".mainArm#detachLimit"));
	frontloader.mainArm = mainArm;
	
	self.parts = {};
	local i=0;
	while true do
		local baseName = string.format(name .. ".parts.part(%d)", i);
        if not hasXMLProperty(xmlFile, baseName) then
            break;
        end;
		local part = {};
		part.node = Utils.indexToObject(self.components, getXMLString(xmlFile, baseName.."#index"));
		part.rotMin = math.rad(getXMLFloat(xmlFile, baseName .. "#minRot"));
		part.rotMax = math.rad(getXMLFloat(xmlFile, baseName .. "#maxRot"));
		part.depTool = getXMLInt(xmlFile, baseName .. "#depMovingTool") + 1;	
		part.inverted = Utils.getNoNil(getXMLBool(xmlFile, baseName .. "#inverted"), false);
		table.insert(self.parts, part);	
		i = i + 1;
	end;	

	self.frontloader = frontloader;
	self.runOnce = false;
end;

function JCBFrontloader:delete()
end;

function JCBFrontloader:mouseEvent(posX, posY, isDown, isUp, button)
end;

function JCBFrontloader:keyEvent(unicode, sym, modifier, isDown)
end;

function JCBFrontloader:update(dt)

end;

function JCBFrontloader:updateTick(dt)
	if self:getIsActive() then
		if self.runOnce then
			for _, part in pairs(self.movingParts) do
				part.isDirty = true;
			end;
			self.runOnce = false;
		end;
		local x,_,_ = getRotation(self.frontloader.mainArm.node);


		for _, part in pairs(self.parts) do	
			local depMovingTool = self.movingTools[part.depTool];
			local maxMovement = math.abs(depMovingTool.rotMin) + depMovingTool.rotMax;
			x,_,_ = getRotation(depMovingTool.node);
			percentage = (math.abs(depMovingTool.rotMax) - x) / maxMovement;
			maxMovement = math.abs(part.rotMin) + part.rotMax;
			if part.inverted then
				percentage = 1 - percentage;
			end;
			newRot = part.rotMin + (percentage * maxMovement);
			setRotation(part.node, newRot, 0, 0);			
		end;	
	end;
end;

function JCBFrontloader:draw()

end;


function JCBFrontloader:attachImplement(implement)
	self.isImplementAttached = true;
end;